@@ -6,7 +6,7 @@ package BSON::Types;
 # ABSTRACT: Helper functions to wrap BSON type classes
 
 use version;
-our $VERSION = 'v1.10.2';
+our $VERSION = 'v1.12.0';
 
 use base 'Exporter';
 our @EXPORT_OK = qw(
@@ -16,6 +16,7 @@ our @EXPORT_OK = qw(
     bson_dbref
     bson_decimal128
     bson_doc
+    bson_array
     bson_double
     bson_int32
     bson_int64
@@ -38,6 +39,7 @@ use BSON::Code;         # bson_code
 use BSON::DBRef;        # bson_dbref
 use BSON::Decimal128;   # bson_decimal128
 use BSON::Doc;          # bson_doc
+use BSON::Array;        # bson_array
 use BSON::Double;       # bson_double
 use BSON::Int32;        # bson_int32
 use BSON::Int64;        # bson_int64
@@ -135,6 +137,19 @@ sub bson_doc {
     return BSON::Doc->new( @_ );
 }
 
+#pod =func bson_array
+#pod
+#pod     $doc = bson_array(...);
+#pod
+#pod This function returns a L<BSON::Array> object, which preserves the order
+#pod of the provided list of elements.
+#pod
+#pod =cut
+
+sub bson_array {
+    return BSON::Array->new( @_ );
+}
+
 #pod =func bson_double
 #pod
 #pod     $double = bson_double( 1.0 );
@@ -337,7 +352,7 @@ BSON::Types - Helper functions to wrap BSON type classes
 
 =head1 VERSION
 
-version v1.10.2
+version v1.12.0
 
 =head1 SYNOPSIS
 
@@ -404,6 +419,13 @@ decimal precision.
 This function returns a L<BSON::Doc> object, which preserves the order
 of the provided key-value pairs.
 
+=head2 bson_array
+
+    $doc = bson_array(...);
+
+This function returns a L<BSON::Array> object, which preserves the order
+of the provided list of elements.
+
 =head2 bson_double
 
     $double = bson_double( 1.0 );
@@ -527,7 +549,7 @@ Stefan G. <minimalist@lavabit.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Stefan G. and MongoDB, Inc.
+This software is Copyright (c) 2019 by Stefan G. and MongoDB, Inc.
 
 This is free software, licensed under:
 
